#!/bin/sh

BASE_URL=http://mirror.voyage.hk/download/voyage-mubox
URL_MUBOX=$BASE_URL/voyage-mubox-current.tar.xz
URL_CUBOXI_BOOT=$BASE_URL/cubox-i/boot-cubox-i-c1.tar.xz
URL_CUBOXI_KERNEL=$BASE_URL/cubox-i/kernel-cubox-i-c1-latest.tar.xz

if [ -z "$1" ] ; then
	echo "Usage: $(basename $0) <install flash dev>"
	exit 1
fi

if [ ! -b "$1" ] ; then
	echo "$1 is not a disk device"
	exit 1
fi 

card=$1
mntpt=/tmp/cf
mntpt1=/tmp/cf1

if [ ! -d "$mntpt" ] ; then mkdir -p $mntpt; fi
if [ ! -d "$mntpt1" ] ; then mkdir -p $mntpt1; fi

checkCmd()
{
	CMD=`which $1`
	if [ -z "$CMD" ] ; then
		echo "Command $1 not found!  Please install it first."
		exit 1
	fi
}

formatCard()
{
# 2 partition , 1 vfat and 1 ext4 w/o journal
[ -b $card ] && fdisk -u $card <<EOF
o
n
p
1
2048
+64M
t
e
a
1
n
p
2


p
w
EOF

# create ext4 filesystem, no mount check and assign volume label
mkfs.vfat -F 16  ${card}1
mkfs.ext4 ${card}2
tune2fs -i 0 -c 0 ${card}2 -L voyage-mubox -O ^has_journal
}

#
# Install Boot
#  $1 - install tarball URL
#
installBoot()
{
	mount ${card}1 ${mntpt}
	curl $1 | tar --numeric-owner -Jxf - -C ${mntpt}

	sync
	
	dd if=${mntpt}/u-boot.imx of=${card} bs=512 seek=2 conv=fsync
	sync

	umount ${mntpt}
	sync
}

#
# Install Root 
#  $1 - install tarball URL
#
installRoot()
{
	mount ${card}2 ${mntpt}
	curl $1 | tar --numeric-owner -Jxf - -C ${mntpt}
	umount ${mntpt}
	sync
}

postInstall()
{
        mount ${card}1 ${mntpt1}
        mount ${card}2 ${mntpt}
	sed -i -e "s/ttyS0/ttymxc0/" ${mntpt}/etc/inittab
	sed -i -e "/^options.*snd-usb-audio/s/^/#/" ${mntpt}/etc/modprobe.d/alsa-base.conf
	cp -rp ${mntpt}/boot/zImage ${mntpt1}

	sync
        umount ${mntpt}
        umount ${mntpt1}
        sync
}


checkCmd dd
checkCmd tar
checkCmd xz
checkCmd mount
checkCmd umount
checkCmd sync
checkCmd fdisk
checkCmd curl
checkCmd mkfs.ext4
checkCmd mkfs.vfat
checkCmd tune2fs
checkCmd find
checkCmd gunzip

formatCard
installBoot $URL_CUBOXI_BOOT
installRoot $URL_MUBOX
installRoot $URL_CUBOXI_KERNEL
postInstall

sync
sleep 5
echo "Voyage MuBox for CuBox-i HummingBoard installed!"

